==> iraf_2.17.1.orig.tar.gz: iraf-2.17.1/README.md <==
# IRAF Release 2.17.1

[![IRAF CI test](https://github.com/iraf-community/iraf/workflows/IRAF%20CI%20test/badge.svg)](https://github.com/olebole/iraf/actions?query=workflow%3A%22IRAF+CI+test%22)
[![GitHub release](https://img.shields.io/github/release/iraf-community/iraf.svg)](https://github.com/iraf-community/iraf/releases/latest)

IRAF is the Image Reduction and Analysis Facility, a general purpose
software system for the reduction and analysis of astronomical
data. IRAF was written by the National Optical Astronomy Observatories
(NOAO) in Tucson, Arizona. However, development and maintenance of
IRAF is discontinued since 2013. The latest release had a large number
of problems, including major license issues and security bugs.

To keep the software away from bitrotting, and to fix bugs that are in
the package despite (or because) of its age, the iraf-community works
on integrating the available patches into the IRAF source code. See
[`RELEASE.md`](RELEASE.md) for the release notes.

For installation instructions see the file [`INSTALL.md`](INSTALL.md)
in this directory.


## Contributing Code, Documentation, or Feedback

IRAF can only survive by the contribution of its users, so we welcome
and encourage your contributions. The preferred way to report a bug is
to create a new issue on the
[IRAF GitHub issue](https://github.com/iraf-community/iraf/issues) page.
To contribute patches, we suggest to create a
[pull request on GitHub](https://github.com/iraf-community/iraf/pulls).


## License

IRAF is licensed under a MIT style license -- see the file
[`COPYRIGHT`](COPYRIGHT). Detailed licensing information for third
party code may be found in the `doc/LICENSES` subdirectory. Note that
all non-free code from the book Numerical Recipes was removed.

==> iraf_2.18.1~rc1.orig.tar.gz: iraf-2.18.1rc1/README.md <==
# IRAF Release 2.18

[![IRAF CI test](https://github.com/iraf-community/iraf/workflows/IRAF%20CI%20test/badge.svg)](https://github.com/olebole/iraf/actions?query=workflow%3A%22IRAF+CI+test%22)
[![GitHub release](https://img.shields.io/github/release/iraf-community/iraf.svg)](https://github.com/iraf-community/iraf/releases/latest)

IRAF is the Image Reduction and Analysis Facility, a general purpose
software system for the reduction and analysis of astronomical
data. IRAF was written by the National Optical Astronomy Observatories
(NOAO) in Tucson, Arizona. However, development and maintenance of
IRAF is discontinued since 2013. The latest release had a large number
of problems, including major license issues and security bugs.

To keep the software away from bitrotting, and to fix bugs that are in
the package despite (or because) of its age, the iraf-community works
on integrating the available patches into the IRAF source code.

For instructions to install from source see the file
[`INSTALL.md`](INSTALL.md) in this directory. Installation
instructions for binary packages on Linux or macOS can be found on the
[Installation web page](https://iraf-community.github.io/install.html).


## Contributing Code, Documentation, or Feedback

IRAF can only survive by the contribution of its users, so we welcome
and encourage your contributions. The preferred way to report a bug is
to create a new issue on the
[IRAF GitHub issue](https://github.com/iraf-community/iraf/issues) page.
To contribute patches, we suggest to create a
[pull request on GitHub](https://github.com/iraf-community/iraf/pulls).


## License

IRAF is licensed under a MIT style license -- see the file
[`COPYRIGHT`](COPYRIGHT). Detailed licensing information for third
party code may be found in the `doc/LICENSES` subdirectory. Note that
all non-free code from the book Numerical Recipes was removed.
